================
 API Reference
================

.. autosummary::
    :toctree:
    :nosignatures:
    :recursive:
    :template: modules.rst

    zennit.attribution
    zennit.canonizers
    zennit.cmap
    zennit.composites
    zennit.core
    zennit.image
    zennit.layer
    zennit.rules
    zennit.torchvision
    zennit.types
